@@ -18,6 +18,7 @@ import argparse
 import fileinput
 import os
 import re
+import shlex
 import subprocess
 import sys
 
@@ -148,8 +149,48 @@ def check_local_subshell(line, report):
 def check_hashbang(line, filename, report):
     # this check only runs on the first line
     #  maybe this should check for shell?
-    if not line.startswith("#!") and not filename.endswith(".sh"):
-        report.print_error(MESSAGES['E005'].msg, line)
+    if (not filename.endswith(".sh") and not line.startswith("#!") and
+       not os.path.basename(filename).startswith('.')):
+            report.print_error(MESSAGES['E005'].msg, line)
+
+
+def check_conditional_expression(line, report):
+    # We're really starting to push the limits of what we can do without
+    # a complete bash syntax parser here.  For example
+    # > [[ $foo =~ " [ " ]] && [[ $bar =~ " ] " ]]
+    # would be valid but mess up a simple regex matcher for "[.*]".
+    # Let alone dealing with multiple-line-spanning etc...
+    #
+    # So we'll KISS and just look for simple, one line,
+    # > if [ $foo =~ "bar" ]; then
+    # type statements, which are the vast majority of typo errors.
+    #
+    # shlex is pretty helpful in getting us something we can walk to
+    # find this pattern.  It does however have issues with
+    # unterminated quotes on multi-line strings (e.g.)
+    #
+    # foo="bar   <-- we only see this bit in "line"
+    #  baz"
+    #
+    # So we're just going to ignore parser failures here and move on.
+    # Possibly in the future we could pull such multi-line strings
+    # into "logical_line" below, and pass that here and have shlex
+    # break that up.
+    try:
+        toks = shlex.shlex(line)
+        toks.wordchars = "[]=~"
+        toks = list(toks)
+    except ValueError:
+        return
+
+    in_single_bracket = False
+    for tok in toks:
+        if tok == '[':
+            in_single_bracket = True
+        elif tok in ('=~', '<', '>') and in_single_bracket:
+            report.print_error(MESSAGES['E044'].msg, line)
+        elif tok == ']':
+            in_single_bracket = False
 
 
 def check_syntax(filename, report):
@@ -255,11 +296,14 @@ class BashateRun(object):
         self.log_error(error, line, filename, filelineno, warn)
 
     def log_error(self, error, line, filename, filelineno, warn=False):
-        print("[%(warn)s] %(error)s: '%(line)s'" %
-              {'warn': "W" if warn else "E",
-               'error': error,
+        # following pycodestyle/pep8 default output format
+        # https://github.com/PyCQA/pycodestyle/blob/master/pycodestyle.py#L108
+        print("%(filename)s:%(filelineno)s:1: %(error)s" %
+              {'filename': filename,
+               'filelineno': filelineno,
+               'warn': "W" if warn else "E",
+               'error': error.replace(":", "", 1),
                'line': line.rstrip('\n')})
-        print(" - %s : L%s" % (filename, filelineno))
 
     def check_files(self, files, verbose):
         logical_line = ""
@@ -363,6 +407,7 @@ class BashateRun(object):
                     check_arithmetic(line, report)
                     check_local_subshell(line, report)
                     check_bare_arithmetic(line, report)
+                    check_conditional_expression(line, report)
 
         # finished processing the file
 
@@ -371,7 +416,10 @@ class BashateRun(object):
             report.print_error(MESSAGES['E004'].msg, line)
 
 
-def main():
+def main(args=None):
+
+    if args is None:
+        args = sys.argv[1:]
 
     parser = argparse.ArgumentParser(
         description='A bash script style checker')
@@ -384,7 +432,7 @@ def main():
                         help='Rules to always error (rather than warn)')
     parser.add_argument('-v', '--verbose', action='store_true', default=False)
     parser.add_argument('-s', '--show', action='store_true', default=False)
-    opts = parser.parse_args()
+    opts = parser.parse_args(args)
 
     if opts.show:
         messages.print_messages()
